#
# spec file for package python3-django-treebeard
#
# Copyright (c) 2016 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-django-treebeard
Version:        4.0.1
Release:        1.6
License:        Apache-2.0
Summary:        Efficient Materialized Path tree implementation for Django 1.0+
Url:            http://code.tabo.pe/django-treebeard
Group:          Development/Libraries/Python
Source:         https://files.pythonhosted.org/packages/source/d/django-treebeard/django-treebeard-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-django
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Django-treebeard is a library that implements efficient tree implementations for the Django Web Framework 1.0+.
It includes 3 different tree implementations: Adjacency List, Materialized Path and Nested Sets. Each one has
it's own strength and weaknesses but share the same API, so it's easy to switch between implementations.

Django-treebeard uses Django Model Inheritance with abstract classes to let you define your own models.
To use django-treebeard:
    - Download a release from the treebeard download page or get a development version from the treebeard mercurial repository;
    - Run python setup.py install;
    - Add 'treebeard' to the INSTALLED_APPS section in your django settings file;
    - Create a new model that inherits from one of django-treebeard's abstract tree models: mp_tree.MP_Node (materialized path), ns_tree.NS_Node (nested sets) or al_tree.AL_Node (adjacency list);
    - Run python manage.py syncdb.

%prep
%setup -q -n django-treebeard-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc CHANGES LICENSE NOTICE README.rst UPDATING docs/*.rst
%{python3_sitelib}/*
%changelog
* Sun May 15 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 4.0.1:
  * Escape input in forms (Martin Koistinen / Divio)
  * Clarification on model detail pages (Michael Huang)
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Thu Dec 31 2015 arun@gmx.de
- update to version 4.0:
  * Added support for 3.5 and Django 1.7, 1.8 and 1.9
  * Django 1.6 is no longer supported.
  * Remove deprecated backports needed for now unsupported Django versions
  * Fixed a bug with queryset deletion not handling inheritance correctly.
  * Assorted documentation fixes
* Tue Jan 20 2015 arun@gmx.de
- specfile:
  * update copryright year
  * dropped patch
  * removed if for opensuseversion <=1100
- dropped fix-setup-utf.patch: included upstream
- update to version 3.0:
  * Limited tests (and hence support) to Python 2.7+/3.4+ and Django 1.6+
  * Removed usage of deprecated Django functions.
  * Fixed documentation issues.
  * Fixed issues in MoveNodeForm
  * Added get_annotated_list_qs and max_depth for get_annotated_list
* Wed Dec 10 2014 arun@gmx.de
- add fix-setup-utf.patch: the readme file is encoded, but setup thinks it's ascii
* Tue Dec  9 2014 arun@gmx.de
- specfile: copied from python2.7 project
  * updated to python3
  * added pypi source link
  * updated copyright year
- update to version 2.0:
  * Support models that use multi-table inheritance (Matt Wescott)
  * Tree methods called on proxy models should consistently return instances
    of that proxy model (Matt Wescott)
  * Fixed unicode related issue in the template tags.
  * Major documentation cleanup.
  * More warnings on the use of managers.
  * Faster MP's is_root() method.
* Sat Sep 28 2013 p.drouand@gmail.com
- Update to version 2.0b2
  + Added support for Django 1.5 and Python 3.X
  + Updated docs: the library supports python 2.5+ and Django 1.4+. Dropped
    support for older versions
  + Revamped admin interface for MP and NS trees, supporting drag&drop to reorder
    nodes. Work on this patch was sponsored by the
  + Updated setup.py to use distribute/setuptools instead of distutils
  + Now using pytest for testing
  + Small optimization to ns_tree.is_root
  + Moved treebeard.tests to it's own directory (instead of tests.py)
  + Added the runtests.py test runner
  + Added tox support
  + Fixed drag&drop bug in the admin
  + Fixed a bug when moving MP_Nodes
  + Using .pk instead of .id when accessing nodes.
  + Removed the Benchmark (tbbench) and example (tbexample) apps.
  + Fixed url parts join issues in the admin.
  + Fixed: Now installing the static resources
  + Fixed ManyToMany form field save handling
  + In the admin, the node is now saved when moving so it can trigger handlers
  and/or signals.
  + Improved translation files, including javascript.
  + Renamed Node.get_database_engine() to Node.get_database_vendor(). As the name
    implies, it returns the database vendor instead of the engine used. Treebeard
    will get the value from Django, but you can subclass the method if needed.
- Use download url as source url
- Add documentation from tarball
- Remove author in description
- Don't use --record-rpm=INSTALLED_FILES; use %%{python_sitelib} in %%files instead
- Fix non-SPDX license
* Mon Jul 26 2010 alexandre@exatati.com.br
- Update to 1.61.
* Mon Apr 19 2010 alexandre@exatati.com.br
- Update to 1.60;
- Spec file cleaned with spec-cleaner.
* Fri Dec 18 2009 alexandre@exatati.com.br
- Update to 1.52.
* Thu Dec 17 2009 alexandre@exatati.com.br
- Initial package (1.51) for openSUSE.
